# GSD-Lite Inbox

<!--
LOOP CAPTURE - ideas, questions, concerns parked here.
All loops get systematic ID: LOOP-NNN (globally unique).

Loops come from TWO sources:
1. User: Non-linear thinker, asks questions mid-task
2. Agent: Discovers dependencies, future work, concerns
-->

## How to Use

- Capture immediately when loop discovered
- Assign next LOOP-NNN ID from STATE.md registry
- Don't interrupt current task to address loop
- Review at phase end for next phase planning
- User can reference by ID: "discuss LOOP-007"

## From User

<!-- User-initiated loops: questions, concerns, ideas during session -->

| ID | Date | Loop | Source | Status |
|----|------|------|--------|--------|
| LOOP-001 | 2026-01-23 | Client Update Workflow (Pulling updates) | During Planning | Open |

## From Agent

<!-- Agent-discovered loops: dependencies, risks, future work -->

| ID | Date | Loop | Source | Status |
|----|------|------|--------|--------|
| LOOP-002 | YYYY-MM-DD | [Discovery/concern] | During TASK-NNN | Open |

## Resolved

<!-- Move here when addressed -->

| ID | Resolution | Date |
|----|------------|------|
| LOOP-001 | [How resolved] | YYYY-MM-DD |

### Example Entries

**From User:**
| ID | Date | Loop | Source | Status |
|----|------|------|--------|--------|
| LOOP-003 | 2026-01-22 | Add password reset flow | During TASK-002 | Open |

**From Agent:**
| ID | Date | Loop | Source | Status |
|----|------|------|--------|--------|
| LOOP-004 | 2026-01-22 | Token expiry strategy unclear | During TASK-001 | Clarifying |

**Resolved:**
| ID | Resolution | Date |
|----|------------|------|
| LOOP-005 | Created PHASE-002 for profile page | 2026-01-23 |

---
*Review before each phase promotion.*